@@ -5,18 +5,22 @@ use vars qw($VERSION @EXPORT_OK);
 use Exporter;
 use base qw(Exporter);
 
-$VERSION = '0.5';
+$VERSION = '0.6';
 
 @EXPORT_OK = qw(NOKEYS NOCERTS INFO CLCERTS CACERTS);
 
 BOOT_XS: {
-	require DynaLoader;
+  require DynaLoader;
 
-	# DynaLoader calls dl_load_flags as a static method.
-	*dl_load_flags = DynaLoader->can('dl_load_flags');
+  # DynaLoader calls dl_load_flags as a static method.
+  *dl_load_flags = DynaLoader->can('dl_load_flags');
 
-	do {__PACKAGE__->can('bootstrap') ||
-		\&DynaLoader::bootstrap}->(__PACKAGE__,$VERSION);
+  do {__PACKAGE__->can('bootstrap') ||
+    \&DynaLoader::bootstrap}->(__PACKAGE__,$VERSION);
+}
+
+END {
+  __PACKAGE__->__PKCS12_cleanup();
 }
 
 1;
@@ -35,9 +39,10 @@ Crypt::OpenSSL::PKCS12 - Perl extension to OpenSSL's PKCS12 API.
   my $pkcs12 = Crypt::OpenSSL::PKCS12->new_from_file('cert.p12');
 
   print $pkcs12->certificate($pass);
+  print $pkcs12->private_key($pass);
 
   if ($pkcs12->mac_ok($pass)) {
-	....
+  ....
 
   $pkcs12->create('test-cert.pem', 'test-key.pem', $pass, 'out.p12', "friendly name");
 
@@ -65,6 +70,10 @@ Create a new Crypt::OpenSSL::PKCS12 instance.
 
 Get the Base64 representation of the certificate.
 
+=item * private_key( [$pass] )
+
+Get the Base64 representation of the private key.
+
 =item * as_string( [$pass] )
 
 Get the binary represenation as a string.
@@ -115,7 +124,7 @@ Dan Sully, E<lt>daniel@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2004-2008 by Dan Sully
+Copyright 2004-2012 by Dan Sully
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
